Esprima: Speed Comparison

# Compare with other parsers

Time measurement is carried out using Benchmark.js.

Esprima version .

Please wait...

Warning: Since each parser may have a different format for the syntax tree, the speed is not fully comparable (the cost of constructing different result is not taken into account). These tests exist only to ensure that Esprima parser is not ridiculously slow compare to other parsers.

parse-js is the parser used in UglifyJS v1. It's a JavaScript port of the Common LISP version. This test uses `parse-js` from UglifyJS version 1.3.2 (June 26 2012).

Acorn is a compact stand-alone JavaScript parser. This test uses Acorn revision 0590d122 (dated Oct 3 2012).

More comparison variants will be added in the near future.